from setuptools import setup

setup(name='matmul',
      version='0.0.2',
      include_package_data=True,
      description='Matrix Multiplication for 2 matrices',
      author='Dhruv Gupta',
      license = "MIT",
      packages=['matmul'],
      zip_safe=False)
